pub struct ReadLock { /* private fields */ }Expand description
Read claim held without a reference to the value.
Useful for keeping a value readable across code that does not touch it. Releases the claim on drop.
Implementations